﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Web.Mvc;

using SchedulerTest.Models;
using System.Web.Security;

using DHTMLX.Scheduler;
using DHTMLX.Scheduler.Controls;
using DHTMLX.Scheduler.Data;
using DHTMLX.Common;


namespace SchedulerTest.Controllers
{
    public class BasicSchedulerController : Controller
    {
        public virtual ActionResult Index()
        {         
            var sched = new DHXScheduler();
            sched.Extensions.Add(SchedulerExtensions.Extension.Recurring);
            sched.Config.multi_day = true;

           // sched.Config.occurrence_timestamp_in_utc = true;

            sched.LoadData = true;
            sched.SaveAction = Url.Action("Save", "BasicScheduler");
            sched.DataAction = Url.Action("Data", "BasicScheduler");
            sched.EnableDataprocessor = true;
            return View(sched);
        }


        public ContentResult Data()
        {
            
            var data = new SchedulerAjaxData((new DHXSchedulerDataContext()).Events);
    

            return data;
        }



        public ActionResult Save(int? id, FormCollection actionValues)
        {
            var action = new DataAction(actionValues);

            DHXSchedulerDataContext data = new DHXSchedulerDataContext();
            try
            {
                var changedEvent = (Event)DHXEventsHelper.Bind(typeof(Event), actionValues);
                //operations with recurring events require some additional handling
                bool isFinished = deleteRelated(action, changedEvent, data);
                if (!isFinished)
                {
                    switch (action.Type)
                    {

                        case DataActionTypes.Insert:
                            data.Events.InsertOnSubmit(changedEvent);
                            if (changedEvent.rec_type == "none")//delete one event from the serie
                                action.Type = DataActionTypes.Delete;
                            break;
                        case DataActionTypes.Delete:
                            changedEvent = data.Events.SingleOrDefault(ev => ev.id == action.SourceId);
                            data.Events.DeleteOnSubmit(changedEvent);
                            break;
                        default:// "update"   
                            var eventToUpdate = data.Events.SingleOrDefault(ev => ev.id == action.SourceId);
                            DHXEventsHelper.Update(eventToUpdate, changedEvent, new List<string>() { "id" });
                            break;
                    }
                }
                data.SubmitChanges();


                action.TargetId = changedEvent.id;
            }
            catch (Exception a)
            {
                action.Type = DataActionTypes.Error;
            }

            return (new AjaxSaveResponse(action));
        }
        protected bool deleteRelated(DataAction action, Event changedEvent, DHXSchedulerDataContext context)
        {
            bool finished = false;
            if ((action.Type == DataActionTypes.Delete || action.Type == DataActionTypes.Update) && !string.IsNullOrEmpty(changedEvent.rec_type))
            {
                context.Events.DeleteAllOnSubmit(from ev in context.Events where ev.event_pid == changedEvent.id select ev);
            }
            if (action.Type == DataActionTypes.Delete && (changedEvent.event_pid != 0 && changedEvent.event_pid != null))
            {
                Event changed = (from ev in context.Events where ev.id == action.TargetId select ev).Single();
                changed.rec_type = "none";
                finished = true;
            }
            return finished;
        }



    }
}
